#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-client-restricted
version:              0.0.4
visibility:           public
id:                   http-client-restricted-0.0.4-Cg78SYPpyOaB2Hqi15yfd4
key:                  http-client-restricted-0.0.4-Cg78SYPpyOaB2Hqi15yfd4
license:              MIT
copyright:            2018 Joey Hess, 2013 Michael Snoyman
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
synopsis:             restricting the servers that http-client will use
description:
    Addition to the http-client and http-client-tls
    libraries, that restricts the HTTP servers that can be used.

    This is useful when a security policy needs to eg, prevent connections to
    HTTP servers on localhost or a local network, or only allow connections
    to a specific HTTP server.

    It handles restricting redirects as well as the initial HTTP connection,
    and it also guards against DNS poisoning attacks.

category:             Network
abi:                  12f0278d99a10951c938eaaf372c0f02
exposed:              True
exposed-modules:      Network.HTTP.Client.Restricted
import-dirs:          /usr/lib/ghc-8.10.5/site-local/http-client-restricted-0.0.4
library-dirs:         /usr/lib/ghc-8.10.5/site-local/http-client-restricted-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/i386-linux-ghc-8.10.5/http-client-restricted-0.0.4

hs-libraries:         HShttp-client-restricted-0.0.4-Cg78SYPpyOaB2Hqi15yfd4
depends:
    base-4.14.2.0 connection-0.3.1-ADJpwCmobBsDFPJVx1SRC3
    data-default-0.7.1.1-5u8NwVJ9HGT30K0bkKsBOX
    http-client-0.7.8-C6JWYZrbeBCPAdb6EpQD6
    http-client-tls-0.3.5.3-1EuJcCGFPgBHafkDNjffQC
    network-3.1.2.2-5EE9GqQpTmvH0oBl8byO4M
    network-bsd-2.8.1.0-J6bIyDlFsUOASjxht9nXWx
    utf8-string-1.0.2-DMovLmOdbFr3ZT2kNNb9Du

haddock-interfaces:
    /usr/share/doc/haskell-http-client-restricted/html/http-client-restricted.haddock

haddock-html:         /usr/share/doc/haskell-http-client-restricted/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

